.. _github-stats-3-8-0:

GitHub statistics for 3.8.0 (Sep 14, 2023)
==========================================

GitHub statistics for 2023/02/13 (tag: v3.7.0) - 2023/09/14

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 185 issues and merged 649 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/77?closed=1>`__

The following 146 authors contributed 2914 commits.

* 0xedl
* Aalok Chhetri
* Adam J. Stewart
* Adam Turner
* Albert Y. Shih
* Alissa
* Alissa Hodge
* Almar Klein
* Andreas Deininger
* Antony Lee
* Artem Shekhovtsov
* Astra
* Ben Root
* Brandon Dusch
* BuildTools
* Caden Gobat
* Chahak Mehta
* Clément Robert
* ColeBurch
* Daniele Nicolodi
* daniilS
* David Kaméus
* David Stansby
* dependabot[bot]
* Devilsaint
* devRD
* Dusch4593
* DWesl
* Eero Vaher
* Elliott Sales de Andrade
* Eric Firing
* Eric Larson
* Eric Prestat
* Eric Wieser
* Evgenii Radchenko
* Fabian Joswig
* Felix Goudreault
* Gabriel Madeira
* Gautam Sagar
* Gokberk Gunes
* Greg Lucas
* Hai Zhu
* hannah
* Haojun Song
* Hasan Rashid
* haval0
* Higgs32584
* Ian Hunt-Isaak
* Ian Thomas
* II-Day-II
* Irtaza Khalid
* j1642
* Jan-Hendrik Müller
* Jarrod Millman
* Jody Klymak
* Johann Krauter
* John Paul Jepko
* Jonathan Wheeler
* jsdodge
* Julian Chen
* kolibril13
* krooijers
* Kyle Sunden
* Larry Bradley
* LemonBoy
* lganic
* Lukas Schrangl
* luke
* marbled-toast
* mariamalykh
* Marisa Wong
* Mateusz Sokół
* Matt Newville
* matt statham
* Matthew Feickert
* Matthew Morrison
* Matthias Bussonnier
* MeeseeksMachine
* Melissa Weber Mendonça
* melissawm
* Michael Dittrich
* Michael Higgins
* Mubin Manasia
* Mudassir Chapra
* Niranjan
* NISHANT KUMAR
* Noy Hanan
* Olin Johnson
* Oscar Gustafsson
* Pavel Zwerschke
* Peter Cock
* Petros Tzathas
* Photoniker
* photoniker
* Pierre Haessig
* Pieter Eendebak
* Prajwal Agrawal
* pre-commit-ci[bot]
* priyanshi
* Priyanshi Gaur
* RadostW
* Rahul Mohan
* Ratnabali Dutta
* rbt94
* Richard Barnes
* richardsheridan
* RishabhSpark
* Rob Righter
* roberto.bodo
* root
* Ruth Comer
* Sam
* saranti
* Scott Shambaugh
* Shreeya Ramesh
* Sia Ghelichkhan
* Sigma-Verma
* Smeet nagda
* SnorfYang
* Stefanie Molin
* Steffen Rehberg
* stevezhang
* stevezhang1999
* Talha Irfan
* Thomas A Caswell
* Thomas J. Fan
* Tigran Khachatryan
* Tim Hoffmann
* Tom
* Tom Sarantis
* Tunç Başar Köse
* Utkarsh Verma
* vavanade
* Vishal Pankaj Chandratreya
* vivekvedant
* vizzy_viz
* Vladimir
* Vladimir Ilievski
* Waleed-Abdullah
* weijili
* whyvra
* xtanion
* Y.D.X
* Yi Wei
* yuzie007
* 渡邉 美希

GitHub issues and pull requests:

Pull Requests (649):

* :ghpull:`26777`: Backport PR #26702 on branch v3.8.x (converted coc to rst and put links in code_of_conduct.md)
* :ghpull:`26775`: Backport PR #26767 on branch v3.8.x (Trim Gouraud triangles that contain NaN)
* :ghpull:`26776`: Backport PR #26687 on branch v3.8.x (Remove usage of recarray)
* :ghpull:`26702`: converted coc to rst and put links in code_of_conduct.md
* :ghpull:`26687`: Remove usage of recarray
* :ghpull:`26767`: Trim Gouraud triangles that contain NaN
* :ghpull:`26770`: Backport PR #26762 on branch v3.8.x (MNT: Numpy 2.0 removals from ndarray class)
* :ghpull:`26762`: MNT: Numpy 2.0 removals from ndarray class
* :ghpull:`26769`: DOC: Pin mpl-sphinx-theme to 3.8.x
* :ghpull:`26768`: Backport PR #26700 on branch v3.8.x (Check type for set_clip_box)
* :ghpull:`26700`: Check type for set_clip_box
* :ghpull:`26766`: Backport PR #26763 on branch v3.8.x (DOC: Add redirects for old gitwash files)
* :ghpull:`26763`: DOC: Add redirects for old gitwash files
* :ghpull:`26756`: Pin numpy to <2 for 3.8.0
* :ghpull:`26761`: Merge branch v3.7.x into v3.8.x
* :ghpull:`26757`: Backport PR #26628 on branch v3.8.x (DOC: move install related FAQ to install docs)
* :ghpull:`26628`: DOC: move install related FAQ to install docs
* :ghpull:`26753`: Backport PR #26705 on branch v3.8.x ([Doc] Small fixes found by velin)
* :ghpull:`26705`: [Doc] Small fixes found by velin
* :ghpull:`26746`: Backport PR #26671 on branch v3.8.x ([DOC] Enhance API reference index)
* :ghpull:`26671`: [DOC] Enhance API reference index
* :ghpull:`26740`: Backport PR #26676 on branch v3.8.x ([DOC] Slightly improve the LineCollection docstring)
* :ghpull:`26676`: [DOC] Slightly improve the LineCollection docstring
* :ghpull:`26712`: Backport PR #26491 on branch v3.8.x (TYP: Add common-type overloads of subplot_mosaic)
* :ghpull:`26726`: Backport PR #26719 on branch v3.8.x (Fix issue with missing attribute in Path3DCollection)
* :ghpull:`26724`: Backport PR #26721 on branch v3.8.x (Add a Python 3.12 classifier)
* :ghpull:`26711`: Backport PR #26709 on branch v3.8.x (DOC: consistency in docstrings of formatting of array-like)
* :ghpull:`26491`: TYP: Add common-type overloads of subplot_mosaic
* :ghpull:`26709`: DOC: consistency in docstrings of formatting of array-like
* :ghpull:`26708`: Backport PR #26601 on branch v3.8.x (Avoid checking limits when updating both min and max for contours)
* :ghpull:`26601`: Avoid checking limits when updating both min and max for contours
* :ghpull:`26701`: Backport PR #26695 on branch v3.8.x (Bump actions/checkout from 3 to 4)
* :ghpull:`26695`: Bump actions/checkout from 3 to 4
* :ghpull:`26694`: Backport PR #26689 on branch v3.8.x (Fix error generation for missing pgf.texsystem.)
* :ghpull:`26522`: TST: Add failing test
* :ghpull:`26689`: Fix error generation for missing pgf.texsystem.
* :ghpull:`26688`: Backport PR #26680 on branch v3.8.x (Fix flaky CI tests)
* :ghpull:`26680`: Fix flaky CI tests
* :ghpull:`26675`: Backport PR #26665 on branch v3.8.x (Clarify loading of backend FigureCanvas and show().)
* :ghpull:`26673`: Backport PR #26193 on branch v3.8.x (Sort tex2uni data in mathtext)
* :ghpull:`26665`: Clarify loading of backend FigureCanvas and show().
* :ghpull:`26193`: Sort tex2uni data in mathtext
* :ghpull:`26663`: Backport PR #26245 on branch v3.8.x ([pre-commit.ci] pre-commit autoupdate)
* :ghpull:`26668`: Backport PR #26541 on branch v3.8.x (TYP: Add typing on mathtext internals)
* :ghpull:`26666`: Backport PR #26657 on branch v3.8.x (DOC: Fix some small issues)
* :ghpull:`26541`: TYP: Add typing on mathtext internals
* :ghpull:`26662`: Backport PR #26542 on branch v3.8.x (TST: Ensure test_webagg subprocess is terminated)
* :ghpull:`26661`: Backport PR #26566 on branch v3.8.x (MAINT: Numpy 2.0 deprecations for row_stack and in1d)
* :ghpull:`26657`: DOC: Fix some small issues
* :ghpull:`26660`: Backport PR #26656 on branch v3.8.x (TYP: Fix some small bugs)
* :ghpull:`26659`: Backport PR #26470 on branch v3.8.x ([DOC]: mathtext tutorial-consolidate explain and notes)
* :ghpull:`26245`: [pre-commit.ci] pre-commit autoupdate
* :ghpull:`26658`: Backport PR #26608 on branch v3.8.x (Removed unnecessary origin keywords)
* :ghpull:`26542`: TST: Ensure test_webagg subprocess is terminated
* :ghpull:`26566`: MAINT: Numpy 2.0 deprecations for row_stack and in1d
* :ghpull:`26656`: TYP: Fix some small bugs
* :ghpull:`26651`: Backport PR #26348 on branch v3.8.x (Test some untested Locator code)
* :ghpull:`26470`: [DOC]: mathtext tutorial-consolidate explain and notes
* :ghpull:`26608`: Removed unnecessary origin keywords
* :ghpull:`26655`: Backport PR #26649 on branch v3.8.x ([DOC] Remove "Discouraged" notices that have been superseded by deprecation)
* :ghpull:`26654`: Backport PR #26597 on branch v3.8.x (Squeeze post-converted values when validating limits)
* :ghpull:`26652`: Backport PR #26646 on branch v3.8.x (Use standard method for closing QApp when last window is closed.)
* :ghpull:`26648`: Backport PR #26521 on branch v3.8.x (Replaced list with tuple in pyplot for axes)
* :ghpull:`26649`: [DOC] Remove "Discouraged" notices that have been superseded by deprecation
* :ghpull:`26647`: Backport PR #26582 on branch v3.8.x (MNT: Enable wheels for Python 3.12)
* :ghpull:`26646`: Use standard method for closing QApp when last window is closed.
* :ghpull:`26650`: Backport PR #26635 on branch v3.8.x ([MNT] Do not configure axes properties via subplots(..., subplot_kw={...}))
* :ghpull:`26644`: Backport PR #26641 on branch v3.8.x ([Doc] Add ACCEPTS for some Axes set methods)
* :ghpull:`26348`: Test some untested Locator code
* :ghpull:`26635`: [MNT] Do not configure axes properties via subplots(..., subplot_kw={...})
* :ghpull:`26521`: Replaced list with tuple in pyplot for axes
* :ghpull:`26643`: Backport PR #26636 on branch v3.8.x ([Doc] Improve set_layout_engine docs)
* :ghpull:`26641`: [Doc] Add ACCEPTS for some Axes set methods
* :ghpull:`26640`: Backport PR #24209 on branch v3.8.x (List the webagg_core module in the sphinx docs.)
* :ghpull:`26638`: Backport PR #26633 on branch v3.8.x ([Doc] Shorten documentation links in widgets)
* :ghpull:`26636`: [Doc] Improve set_layout_engine docs
* :ghpull:`24209`: List the webagg_core module in the sphinx docs.
* :ghpull:`26633`: [Doc] Shorten documentation links in widgets
* :ghpull:`26632`: Backport PR #26540 on branch v3.8.x (TYP: Add overloads for FT2Font.get_sfnt_table)
* :ghpull:`26631`: Backport PR #26619 on branch v3.8.x ([DOC] Clarify some tick-related docstrings)
* :ghpull:`26540`: TYP: Add overloads for FT2Font.get_sfnt_table
* :ghpull:`26619`: [DOC] Clarify some tick-related docstrings
* :ghpull:`26625`: Backport PR #26622 on branch v3.8.x ([Doc] Improve DSP-related examples)
* :ghpull:`26622`: [Doc] Improve DSP-related examples
* :ghpull:`26618`: Backport PR #24711 on branch v3.8.x (Test with Python 3.12)
* :ghpull:`26617`: Backport PR #26598 on branch v3.8.x (FIX: array labelcolor for Tick)
* :ghpull:`26615`: Backport PR #26614 on branch v3.8.x (Properly disconnect machinery when removing child axes.)
* :ghpull:`26614`: Properly disconnect machinery when removing child axes.
* :ghpull:`24711`: Test with Python 3.12
* :ghpull:`26607`: Backport PR #26606 on branch v3.8.x ([Doc] Revise histogram features example (Closes #26604))
* :ghpull:`26606`: [Doc] Revise histogram features example (Closes #26604)
* :ghpull:`26599`: Backport PR #26565 on branch v3.8.x ([doc]: added section Verify installation)
* :ghpull:`26565`: [doc]: added section Verify installation
* :ghpull:`26595`: Backport PR #26591 on branch v3.8.x (Fix ToolBase.figure property setter.)
* :ghpull:`26591`: Fix ToolBase.figure property setter.
* :ghpull:`26584`: Backport PR #26581 on branch v3.8.x (Deduplicate test for toolbar button icon LA mode.)
* :ghpull:`26585`: Backport PR #26576 on branch v3.8.x (Use sys.platform over os.name)
* :ghpull:`26583`: Backport PR #26578 on branch v3.8.x (MAINT: add __pycache__/ to .gitignore)
* :ghpull:`26576`: Use sys.platform over os.name
* :ghpull:`26581`: Deduplicate test for toolbar button icon LA mode.
* :ghpull:`26578`: MAINT: add __pycache__/ to .gitignore
* :ghpull:`26579`: Backport PR #26572 on branch v3.8.x ([DOC]: clarify pre-commits and editing workflow)
* :ghpull:`26572`: [DOC]: clarify pre-commits and editing workflow
* :ghpull:`26575`: Backport PR #26573 on branch v3.8.x ([DOC]: codespace link in contribute index)
* :ghpull:`26573`: [DOC]: codespace link in contribute index
* :ghpull:`26568`: Backport PR #26462 on branch v3.8.x (Boxplot fix median line extending past box boundaries #19409)
* :ghpull:`26416`: [doc]: add 'validate' section to install docs #26379
* :ghpull:`26564`: Backport PR #26543 on branch v3.8.x (Add ninja to Cygwin builder)
* :ghpull:`26462`: Boxplot fix median line extending past box boundaries #19409
* :ghpull:`26563`: Backport PR #26519 on branch v3.8.x (Fix mathtext mismatched braces)
* :ghpull:`26543`: Add ninja to Cygwin builder
* :ghpull:`26519`: Fix mathtext mismatched braces
* :ghpull:`26556`: Backport PR #26554 on branch v3.8.x (Remove NumPy abs overrides from pylab)
* :ghpull:`26550`: Backport PR #26545 on branch v3.8.x (Fix size inferral when using cairocffi)
* :ghpull:`26547`: Backport PR #26493 on branch v3.8.x (Disable ````add_html_cache_busting```` on Sphinx 7.1+)
* :ghpull:`26546`: Backport PR #26201 on branch v3.8.x (DOC: Add documentation on codespaces usage)
* :ghpull:`26548`: Backport PR #26514 on branch v3.8.x (Clarify interaction between params of get_path_collection_extents.)
* :ghpull:`26514`: Clarify interaction between params of get_path_collection_extents.
* :ghpull:`26537`: Backport PR #26529 on branch v3.8.x (Fix MathText antialiasing)
* :ghpull:`26536`: Backport PR #26532 on branch v3.8.x (Fix input check in Poly3DCollection.__init__)
* :ghpull:`26529`: Fix MathText antialiasing
* :ghpull:`26534`: Backport PR #26513 on branch v3.8.x (Tweak shape repr in _api.check_shape error message.)
* :ghpull:`26533`: Backport PR #26526 on branch v3.8.x (Bump pypa/cibuildwheel from 2.14.1 to 2.15.0)
* :ghpull:`26513`: Tweak shape repr in _api.check_shape error message.
* :ghpull:`26526`: Bump pypa/cibuildwheel from 2.14.1 to 2.15.0
* :ghpull:`26201`: DOC: Add documentation on codespaces usage
* :ghpull:`26530`: Backport PR #26509 on branch v3.8.x (Update/tweak SpanSelector docs.)
* :ghpull:`26509`: Update/tweak SpanSelector docs.
* :ghpull:`26528`: Backport PR #26504 on branch v3.8.x (TYP: Add overload to specify output of Colormap.__call__ when possible)
* :ghpull:`26527`: Backport PR #26173 on branch v3.8.x (Synchronize mathtext docs and handling)
* :ghpull:`26504`: TYP: Add overload to specify output of Colormap.__call__ when possible
* :ghpull:`26173`: Synchronize mathtext docs and handling
* :ghpull:`26511`: Backport PR #26490 on branch v3.8.x (Import PIL.Image explicitly over PIL)
* :ghpull:`26490`: Import PIL.Image explicitly over PIL
* :ghpull:`26503`: Backport PR #26502 on branch v3.8.x (TST: Increase some tolerances for non-x86 arches)
* :ghpull:`26502`: TST: Increase some tolerances for non-x86 arches
* :ghpull:`26499`: Backport PR #26498 on branch v3.8.x (Add plausible analytics to the documentation pages)
* :ghpull:`26498`: Add plausible analytics to the documentation pages
* :ghpull:`26493`: Disable ````add_html_cache_busting```` on Sphinx 7.1+
* :ghpull:`26489`: Backport PR #26487 on branch v3.8.x (DOC: Remove unused image rotator)
* :ghpull:`26487`: DOC: Remove unused image rotator
* :ghpull:`26479`: ps: Add option to use figure size as paper size
* :ghpull:`26469`: Deprecate PdfPages(keep_empty=True).
* :ghpull:`24379`: DOC: Update dropped splines example
* :ghpull:`26326`: Only do pchanged and set stale when value changes + doc consistency
* :ghpull:`26443`: BLD: stop skipping musl wheel builds
* :ghpull:`26475`: [DOC]: Noto Sans for windows docs builds
* :ghpull:`26481`: Clarify behavior of norm clipping
* :ghpull:`26474`: [DOC]: filter non-gui backend warnings when building docs
* :ghpull:`26480`: [DOC] Documentation fixes
* :ghpull:`26476`: Remove auto from supported ps.papersizes in matplotlibrc.
* :ghpull:`25966`: Fix support for Ctrl-C on the macosx backend.
* :ghpull:`26473`: Fix codespaces setup.sh script
* :ghpull:`24376`: Support removing inner ticks in label_outer()
* :ghpull:`25785`: Deprecate papersize=auto in PostScript
* :ghpull:`26472`: Do not close figures on backend switch.
* :ghpull:`26402`: Restructure interface section of API Reference index page
* :ghpull:`26467`: MNT: Adjust for upcoming numpy repr changes
* :ghpull:`26451`: TYP: Add several missing return type annotations
* :ghpull:`26466`: Make annotate/OffsetFrom unaffected by later mutation of coordinates.
* :ghpull:`26445`: [DOC]: annotation tutorial: blended artist, headers, and user demo deletes
* :ghpull:`26454`: Rename an internal parameter of _label_outer_x/yaxis()
* :ghpull:`26130`: Enable branch coverage for C/C++ code
* :ghpull:`26448`: [DOC] Update dependency documentation
* :ghpull:`26450`: Fix return value of Text.update
* :ghpull:`26447`: DOC: Fix accidental cases of blockquotes
* :ghpull:`26401`: WARN: more direct warning ticklabels
* :ghpull:`26444`: Fix some bugs found by typing
* :ghpull:`26253`: Filter out inf values in plot_surface
* :ghpull:`26407`: Improve some smaller typing issues
* :ghpull:`26328`: [DOC]: improve consistency of plot types gallery
* :ghpull:`26434`: TYP: Adjust type hint of Norm.__call__ to return masked array
* :ghpull:`26376`: Text antialiasing for mathtext (reopen)
* :ghpull:`25830`: Specify ticks and axis label positions for 3D plots
* :ghpull:`25784`: ps: Fix anchoring of rotated usetex text
* :ghpull:`26403`: Update type hints for font manager and extension
* :ghpull:`26433`: Call out which pane is hovered over for 3d hover coordinates
* :ghpull:`26418`: Add next_whats_new entries for mathtext features
* :ghpull:`26429`: DOC: update ContourSet attributes deprecation advice
* :ghpull:`26051`: Type hinting developer docs
* :ghpull:`26427`: Improve button widget examples a bit
* :ghpull:`26423`: Fix pyparsing version check
* :ghpull:`26425`: Delete second MRI demo example
* :ghpull:`26424`: macos: Don't leak None in Timer cleanup
* :ghpull:`26332`: moved doc root to landing page, make user landing a guide page
* :ghpull:`26408`: DOC: add note about manually downloading qhull + freetype
* :ghpull:`26404`: Remove old What's new entries
* :ghpull:`26011`: Emit xlim_changed on shared axes.
* :ghpull:`25810`: Fix default return of Collection.get_{cap,join}style
* :ghpull:`26168`: Add _val_or_rc-function
* :ghpull:`26335`: Optimize imshow
* :ghpull:`26367`: Add typing for internal helpers
* :ghpull:`26397`: TYP: Add type hints to testing module
* :ghpull:`26399`: Reinstate & deprecate ContourSet.antialiased
* :ghpull:`26385`: Improve typing in pyplot
* :ghpull:`26151`: Add substack cmd for mathtext
* :ghpull:`26396`: Move pylab documentation to its own module page
* :ghpull:`26393`: TST: Remove extra dummy Axis classes
* :ghpull:`26384`: Fix triage tool due to Qt bump to 5.12
* :ghpull:`26382`: Tweak hist2d docstring.
* :ghpull:`26359`: Simplify MRI with EEG example
* :ghpull:`26071`: ENH: macosx allow figures to be opened in tabs or windows
* :ghpull:`16473`: Make ``.axis(zmin=...)`` work on 3D axes
* :ghpull:`26333`: Add middle for delims
* :ghpull:`26365`: Fix removal of Figure-level artists
* :ghpull:`26341`: Fix pickling of axes property cycle.
* :ghpull:`26279`: DOC: remove users_explain/axis
* :ghpull:`26347`: Add tests for LogFormatter.format_data and format_data_short
* :ghpull:`26329`: Clarify that ImageGrid requires limits-sharing.
* :ghpull:`26349`: Tweak Sankey docs.
* :ghpull:`26352`: Fix bad histogramming bins in mri/eeg example.
* :ghpull:`26353`: Remove unused private method
* :ghpull:`26342`: ENH: Collection.set_paths
* :ghpull:`26344`: Some more micro optimizations
* :ghpull:`26346`: Increase coverage
* :ghpull:`26330`: Deprecate wrappers combining axes_grid1 and axisartist.
* :ghpull:`26338`: Bump pypa/cibuildwheel from 2.14.0 to 2.14.1
* :ghpull:`26331`: Support standard Axes in RGBAxes.
* :ghpull:`26219`: DOC: Restore banner indicating docs are unreleased
* :ghpull:`25558`: Simplify outdated Image.contains check.
* :ghpull:`26324`: More micro optimizations of plot
* :ghpull:`26325`: Remove unused variables
* :ghpull:`26022`: MNT/FIX: macosx change Timer to NSTimer instance
* :ghpull:`26303`: Micro optimization of plotting
* :ghpull:`26249`: FIX: axes3d.scatter color parameter doesn't decrease in size for non-finite coordinate inputs.
* :ghpull:`26078`: Fix parasite_axes does not properly handle units
* :ghpull:`25839`: [ENH]: int / float-tuple like kwarg legend(loc) for rcParams['legend.loc']
* :ghpull:`26056`: Privatize TexManager.texcache
* :ghpull:`25363`: Bump minimum QT5 version to 5.12
* :ghpull:`26176`: Add more sizeable delimiters
* :ghpull:`26302`: FIX: move the font lock higher up the call and class tree
* :ghpull:`26309`: qt: Mark canvas for re-draw after savefig
* :ghpull:`26311`: FIX: labels at start of contours
* :ghpull:`26278`: ENH: clip_path keyword for contour and contourf
* :ghpull:`26295`: Deprecate inset_locator.InsetPosition.
* :ghpull:`26122`: Only change axes aspect in imshow if image transform is/contains transData
* :ghpull:`26297`: Use transformed paths for contour labelling decisions
* :ghpull:`26160`: add setters and getters for _AxLine's xy1, xy2 and slope parameters
* :ghpull:`26294`: Deprecate cbook.Stack.
* :ghpull:`26284`: Bump pypa/cibuildwheel from 2.13.1 to 2.14.0
* :ghpull:`25661`: boldsymbol support for mathtext
* :ghpull:`26285`: Improve exception message for set_ticks() kwargs without labels
* :ghpull:`14593`: Simplify SecondaryAxis.set_color.
* :ghpull:`26273`: TST: simplify mask in pcolor writing to mask test
* :ghpull:`26263`: Doc fix toc users
* :ghpull:`26242`: Deprecate FigureCanvasBase.switch_backends.
* :ghpull:`26164`: Only clear Axis once when creating an Axes
* :ghpull:`26035`: issue #26031 -  [MNT]: decrease timeout on interactive tests locally
* :ghpull:`23485`: Fix displayed 3d coordinates showing gibberish
* :ghpull:`25027`: Make pcolor more mesh-like
* :ghpull:`26235`: MNT:Decreased timeout for local interactive tests
* :ghpull:`26270`: Merge v3.7.x into main
* :ghpull:`26269`: DOC: Fix image_rotator
* :ghpull:`26265`: DOC: ensure that the bounding box is scaled with dpi in example
* :ghpull:`26255`: DOC: Modernize Colorbar Tick Labelling example
* :ghpull:`26258`: DOC: fix rst formatting
* :ghpull:`26257`: DOC: Clarify terminology
* :ghpull:`26256`: Better document the ContourSet API change.
* :ghpull:`26254`: DOC: Improve readability of date formatters/locators example
* :ghpull:`26233`: DOC: replaced step with stairs in basic plot types
* :ghpull:`26213`: Add ``CITATION.cff`` file
* :ghpull:`26226`: Use CLOSEPOLY kind code to close tricontourf polygons
* :ghpull:`26208`: FIX: also copy the axis units when creating twins
* :ghpull:`26185`: Set transform for offset text in 3d
* :ghpull:`26068`: Rewrite Tick formatters example
* :ghpull:`26218`: moved minimum dependencies to maintenance section
* :ghpull:`26217`: Doc/rm maintainer wf
* :ghpull:`26212`: Avoid deprecated typing hints
* :ghpull:`26198`: Limit Forward references in Mathtext parser
* :ghpull:`26210`: Re-export textpath types in text
* :ghpull:`25247`: Turn ContourSet into a standard Collection artist.
* :ghpull:`26204`: ci: Add tzdata to nightly builds
* :ghpull:`26200`: [Doc] Add note about (str, alpha) version added
* :ghpull:`26171`: precommit warns on main + instructions for fix
* :ghpull:`26189`: Factor out legend/figlegend nargs validation.
* :ghpull:`26199`: ci: Fix typo for nightly builds
* :ghpull:`26197`: CI: Add pre-release installs to upcoming tests
* :ghpull:`26086`: reorganize contributing landing page
* :ghpull:`17497`: Dedupe some C++ templates
* :ghpull:`26190`: Deprecate removal of explicit legend handles whose label starts with _.
* :ghpull:`26188`: Add note to remove texts in baselines when they are regenerated.
* :ghpull:`25714`: Fix ffmpeg framerates
* :ghpull:`26142`: [Doc] alphabetize mathtext symbols by unicode
* :ghpull:`25933`: Relational Operators for mathtext
* :ghpull:`26159`: DOC: Remove unused static images
* :ghpull:`25913`: DOC: contributing and documenting clean ups + community for incubator invites
* :ghpull:`26141`: Doc cards user explain
* :ghpull:`26110`: DOC: fix levels in user/explain/figure
* :ghpull:`26102`: Start basing mathtext tutorial on mathtext parser
* :ghpull:`26138`: MNT: add VNClte porte by default
* :ghpull:`26089`: Add public method to update ``Legend`` object's loc property .
* :ghpull:`26137`: Add codespaces configuration
* :ghpull:`25548`: FIX: macosx keep track of mouse up/down for cursor hand changes
* :ghpull:`26132`: MNT: remove test images from mathtext tests that have been removed
* :ghpull:`26125`: Stop building universal2 and win32 wheels
* :ghpull:`26105`: Doc user guide cards
* :ghpull:`26128`: Add missing spacer in tk toolmanager toolbar.
* :ghpull:`26129`: Remove outdated comment in ``Artist.__getstate__``
* :ghpull:`25631`: API: forbid unsafe savefig kwargs to AbstractMovieWriter.grab_frame
* :ghpull:`25926`: DOC: restore navigation documentation
* :ghpull:`24666`: Setting color of legend shadow
* :ghpull:`26010`: Correct Unicode for [lg]napprox
* :ghpull:`26120`: Fix new warnings in compiled extensions
* :ghpull:`26060`: Mnt: GUI tests
* :ghpull:`25623`: Use classic style in old what's new entries
* :ghpull:`26113`: Fixes #12926 - inconsistency upon passing C in hexbin
* :ghpull:`25555`: Let widgets/clabel better handle overlapping axes.
* :ghpull:`26114`: Bump pypa/cibuildwheel from 2.13.0 to 2.13.1
* :ghpull:`26112`: Skip tests for users-explain gallery
* :ghpull:`26111`: [MNT] Update nightly wheels install location
* :ghpull:`25779`: Adding ellipse_arrow.py example and closes #25477
* :ghpull:`26101`: Correct bounding box calculation for text markers
* :ghpull:`26096`: FIX: Handle masked arrays for RGBA input with ScalarMappables
* :ghpull:`26024`: Add missing operators code
* :ghpull:`26072`: Pcolormesh with Gouraud shading: masked arrays
* :ghpull:`25381`: ENH: switch mpl_toolkits to implicit namespace package (PEP 420)
* :ghpull:`26070`: Factor out common checks for set_data in various Image subclasses.
* :ghpull:`26091`: Shorten axes_grid1 inset_locator code.
* :ghpull:`26090`: ci: Move Python 3.11 job to Ubuntu 22.04
* :ghpull:`21054`: Deprecate many single-use rc validators.
* :ghpull:`26065`: Install extra requirements when testing with 3.11 on GH
* :ghpull:`26080`: Deprecate unused "frac" key in annotate() arrowprops.
* :ghpull:`25248`: added Ishikawa plot in response to issue #25222 add organizational ch…
* :ghpull:`26064`: add ishikawa diagram to examples
* :ghpull:`26079`: Tweak Annotation docstring.
* :ghpull:`26069`: Tweak AnnotationBbox coords specification.
* :ghpull:`26073`: Cleanup date tick locators and formatters
* :ghpull:`26057`: Further cleanup rainbow_text example.
* :ghpull:`26058`: Don't show type hints in rendered docs
* :ghpull:`26042`: Further simplify AxesGrid._init_locators.
* :ghpull:`25993`: Modify rainbow_text() function to use annotate() function
* :ghpull:`25850`: Handle exceptions in numpy::array_view<...>::set().
* :ghpull:`25542`: ENH: offset parameter for MultipleLocator
* :ghpull:`25515`: DOC/BLD: plot directive srcset
* :ghpull:`26045`: 'Inactive' workflow: reduce run frequency
* :ghpull:`26047`: PR welcome: getting attention
* :ghpull:`26023`: CI: Use scientific-python/upload-nightly-action
* :ghpull:`25775`: Support customizing antialiasing for text and annotation
* :ghpull:`26036`: Cleanup AxesGrid
* :ghpull:`26025`: MNT: Use commit SHA of cibuildwheel action release
* :ghpull:`25938`: “Inactive” workflow: bump operations to 175
* :ghpull:`26020`: Let AxesGrid support Axes subclasses that don't override axis().
* :ghpull:`26017`: MNT: reduce number of implicit imports from toplevel __init__.py
* :ghpull:`26033`: removed wrapping from first-issue-bot
* :ghpull:`26003`: added alias to gray and grey match same colormaps
* :ghpull:`26027`: Correct spelling in 'Good first issue'
* :ghpull:`26026`: Simplify delaxes.
* :ghpull:`26028`: Better document the semantics of get_text_width_height_descent.
* :ghpull:`26018`: good first issue bot rewording
* :ghpull:`13482`: Allow sharing Locators and Formatters across Axises.
* :ghpull:`25950`: Upload nightlies to new location
* :ghpull:`25473`: ci: Merge sdist and wheel building workflows
* :ghpull:`25825`: Fix MarkerStyle types
* :ghpull:`26002`: Bump pypa/cibuildwheel from 2.12.3 to 2.13.0
* :ghpull:`25999`: "Inactive" workflow: add close label for inactive issues
* :ghpull:`24493`: DOC: dropdowns in userguide
* :ghpull:`25970`: FIX: resolve an issue where no ticks would be drawn for a colorbar with SymLogNorm and ranging exactly from 0 to linthresh
* :ghpull:`25989`: test annotate(textcoords=offset fontsize)
* :ghpull:`25044`: Modify ``hexbin`` to respect :rc:``patch.linewidth``
* :ghpull:`25667`: Fix bar datetime
* :ghpull:`25794`: Raise on plural scatter
* :ghpull:`25986`: Remove unused/unnecessary parts of _macosx.m View.
* :ghpull:`25689`: Update watermark example
* :ghpull:`25735`: Add comment on issues marked 'good first issue'
* :ghpull:`25968`: Cleanup scalarformatter.py example.
* :ghpull:`18715`: Allow setting default AutoMinorLocator
* :ghpull:`25961`: Fix nightly CI
* :ghpull:`25844`: [TYP] Reduce stubtest ignores
* :ghpull:`25952`: Switch from provision-with-micromamba to setup-micromamba
* :ghpull:`25940`: Cleanups to Annotation.
* :ghpull:`25948`: DOC: don't advocate deleting main branch
* :ghpull:`25939`: Cleanup time_series_histogram example.
* :ghpull:`25883`: Check gridspecness of colorbars on the right figure.
* :ghpull:`25904`: Support spine.set() in SpinesProxy.
* :ghpull:`25909`: #25900 update figure.py
* :ghpull:`25746`: Tick label font family via tick_params
* :ghpull:`25787`: [TYP/MNT] Remove unused imports from stub files
* :ghpull:`25891`: Adds tests for nargs_err in legend, stem, pcolorfast and cycler.
* :ghpull:`25886`: Simplify isort config.
* :ghpull:`25889`: Deprecate CbarAxesBase.toggle_label.
* :ghpull:`25884`: Correctly pass location when constructing ImageGrid colorbar.
* :ghpull:`25888`: Fix incorrect doc references.
* :ghpull:`25885`: Cleanup demo_axes_grid{,2}.
* :ghpull:`25872`: MNT: update Shadow init signature
* :ghpull:`25389`: Add configuration of Shadow and pie shadow
* :ghpull:`25859`: Deprecate passing extra arguments to Figure.add_axes
* :ghpull:`25863`: Fix incorrect usage of nargs_error.
* :ghpull:`25845`: more explicit about what remote means in context
* :ghpull:`23888`: Fix PolygonSelector.clear()
* :ghpull:`25848`: Simplify lasso_demo example.
* :ghpull:`25841`: Deprecate Tick.set_label{1,2}.
* :ghpull:`25728`: Remove and deprecate unused methods in src
* :ghpull:`25843`: Fix invalid range validators.
* :ghpull:`25821`: 3D plots shared view angles
* :ghpull:`25726`: Replace usage of WenQuanYi Zen Hei by Noto Sans CJK
* :ghpull:`25828`: DOC: add remote upstream
* :ghpull:`25814`: [TYP] Correct type hint for Transform.transform return
* :ghpull:`25812`: Fix typo in ruff config
* :ghpull:`25807`: Users guide->User guide
* :ghpull:`25799`: Discourage fontdict
* :ghpull:`25798`: [DOC/TYP]: Allow any array like for set_[xy]ticks, not just list of float
* :ghpull:`25632`: Include data kwarg in pyi stubs
* :ghpull:`25790`: Document default value of corner_mask in the corresponding example.
* :ghpull:`25788`: ci: Increase retry count on PR conflict check
* :ghpull:`25482`: Draw 3D gridlines below axis lines, labels, text, and ticks
* :ghpull:`25607`: Missing return type hints for Figure
* :ghpull:`25783`: Cleanup demo_text_path.
* :ghpull:`25780`: Shorten anchored_artists example.
* :ghpull:`25781`: Deprecate AnchoredEllipse.
* :ghpull:`25786`: DOC: Fix minor typo in API change notes
* :ghpull:`25773`: condensed pull request template
* :ghpull:`25712`: Prevents axes limits from being resized by axes.fill_between
* :ghpull:`25782`: Fix release note reference to pyplot.axis
* :ghpull:`25777`: Cleanup demo_axes_divider.
* :ghpull:`25774`: Small axislines.Axes cleanups.
* :ghpull:`25772`: Only print actually tested QT APIs when erroring
* :ghpull:`25769`: Set PostScript language level to 3
* :ghpull:`25753`: Update, correct, and add badges/links
* :ghpull:`25747`: Tweak axis_direction demo.
* :ghpull:`23059`: FIX: Decrease figure refcount on close of a macosx figure
* :ghpull:`25606`: [pre-commit.ci] pre-commit autoupdate
* :ghpull:`25752`: Enable lazy-loading of images in HTML docs
* :ghpull:`25648`: Remove nonfunctional Axes3D.set_frame_on and get_frame_on methods.
* :ghpull:`25479`: FIX: Allow different colormap name from registered name
* :ghpull:`25763`: Bump pypa/cibuildwheel from 2.12.1 to 2.12.3
* :ghpull:`24661`: Plots first and last minor ticks #22331
* :ghpull:`25759`: Fix typo in api_interfaces.rst
* :ghpull:`20214`: Move AxisArtistHelpers to toplevel.
* :ghpull:`25737`: Update PULL_REQUEST_TEMPLATE.md to include issue cross-reference.
* :ghpull:`25729`: Cleanup GridHelperCurveLinear/GridFinder.
* :ghpull:`25730`: Add test for Path.contains_path
* :ghpull:`25359`: Add bfit bolditalic tex cmd
* :ghpull:`25739`: grammar/wording tweak for backports
* :ghpull:`25597`: Add (color, alpha) tuple as a valid ColorType in typing.py
* :ghpull:`25324`: Fix axes vlines and hlines using wrong coordinates
* :ghpull:`25713`: Remove print_figure overrides in backend subclasses
* :ghpull:`25719`: TYP: Clean up CapStyle/FillStyle type hints
* :ghpull:`25720`: ci: Set apt to retry operations on failure
* :ghpull:`25722`: DOC: Fix duplicated words
* :ghpull:`25584`: Expire remaining 3.6 deprecations
* :ghpull:`25721`: TST: Handle missing black more resiliently
* :ghpull:`25718`: Improve color documentation and typing
* :ghpull:`25652`: DOC: clarify the milestoning and backport policy wording
* :ghpull:`25711`: TYP: allow for xlim/ylim passed as single tuple
* :ghpull:`25594`: changed to RST
* :ghpull:`25708`: Deprecate unused NavigationToolbar2QT signal.
* :ghpull:`25618`: DOC: fix Sphinx Gallery discussion to explain mixed subddirs
* :ghpull:`25710`: TYP: Fix type hint (and docstring) for Bbox.intersection
* :ghpull:`25707`: CI: skip Azure Pipelines for doc-only change
* :ghpull:`25686`: Add Figure methods get_suptitle(), get_subxlabel(), get_supylabel()
* :ghpull:`25697`: Annotation cleanups.
* :ghpull:`25586`: Post stubtest results to GitHub checks
* :ghpull:`25696`: Use true positional args in check_foo APIs instead of simulating them.
* :ghpull:`25698`: Fix codecov.yml so it is valid.
* :ghpull:`25687`: More informative exception messages
* :ghpull:`25692`: Fixed bug: mathtext rendered width not being calculated correctly
* :ghpull:`25690`: TST: Import MatplotlibDeprecationWarning consistently
* :ghpull:`22286`: Fixed ``eventplot`` issues
* :ghpull:`25656`: DOC: update/fix autoscaling documentation
* :ghpull:`25668`: Fix what's new note for text
* :ghpull:`25651`: MNT: deprecate unused numdecs LogLocator param
* :ghpull:`25655`: Clean up FileIO type hints
* :ghpull:`25664`: Fix 'can not' -> 'cannot' typo
* :ghpull:`25657`: Bump cygwin/cygwin-install-action from 3 to 4
* :ghpull:`25640`: pgf: Add clipping to text outputs
* :ghpull:`25639`: Fixing typos
* :ghpull:`25647`: Pin mypy to v1.1.1 for CI
* :ghpull:`25588`: Rename parameters for consistency
* :ghpull:`25628`: Bump invalid hatch removal
* :ghpull:`25610`: DOC: Update user_explain\text\README.txt to reference example page
* :ghpull:`25587`: Ensure tinypages ignored by mypy/stubtest
* :ghpull:`25609`: Use _api.nargs_error in more places
* :ghpull:`25414`: DOC: add a note about linewidth to scatter docs
* :ghpull:`23199`: Do not set clip path if it exists
* :ghpull:`22173`: Support ``\text`` in ``mathtext``
* :ghpull:`24312`: Deprecate axes_divider.AxesLocator.
* :ghpull:`24969`: Optimize C code
* :ghpull:`25501`: FIX: Tk photoimage resize
* :ghpull:`25565`: making sure colors has the attribute size
* :ghpull:`25583`: MNT: use less eval
* :ghpull:`25569`: Use raw instead of png for font manager memory leak test
* :ghpull:`25253`: Use pybind11 in ttconv module
* :ghpull:`24976`: Initial implementation of type stubs (mypy/PEP484)
* :ghpull:`25576`: Skip pgf pdflatex text if cm-super is not installed
* :ghpull:`24991`: Fix issue with shared log axis
* :ghpull:`25221`: Add links and expand mathmpl docstring
* :ghpull:`25498`: FIX: Use mappable data when autoscaling colorbar norm
* :ghpull:`25570`: Use symbolic operator names (moveto, lineto) in contour_manual example.
* :ghpull:`25559`: Make guiEvent available only within the event handlers.
* :ghpull:`25405`: Fix incorrect stride calculations in LogLocator.tick_values()
* :ghpull:`25226`: Fix unintended space after comma as a decimal separator
* :ghpull:`25563`: Add pytest==7.0.0 on requirements/testing/minver.txt
* :ghpull:`25553`: FIX: macosx, always put timers on main thread
* :ghpull:`25557`: Rename parameter of Annotation.contains and Legend.contains.
* :ghpull:`25564`: Bump actions/stale from 7 to 8
* :ghpull:`25562`: Add pytest==3.6.0 on requirements/testing/minver.txt
* :ghpull:`25551`: Restore autolimits status when pressing "home" key.
* :ghpull:`25554`: Remove unused private SpanSelector._pressv and ._prev.
* :ghpull:`25546`: In Artist.contains, check that moussevents occurred on the right canvas.
* :ghpull:`24728`: Add Axes.ecdf() method.
* :ghpull:`25291`: Limit full-invalidation of CompositeGenericTransforms.
* :ghpull:`25550`: "Inactive" workflow: bump operations to 150
* :ghpull:`25539`: Remove explicit symbol visibility pragmas
* :ghpull:`25502`: DOC: Suggest replacement for tostring_rgb
* :ghpull:`25532`: Annotations tutorial
* :ghpull:`25456`: Expire more mpl3.6 deprecations.
* :ghpull:`25505`: DOC: combine marker examples
* :ghpull:`25510`: Remove unnecessary calls to Formatter.set_locs.
* :ghpull:`25487`: DOC/BLD: stop using sg head [ci doc]
* :ghpull:`25507`: gitignore doc/users/explain
* :ghpull:`25504`: "Inactive" workflow: bump operations to 125
* :ghpull:`24691`: ENH: Add option to define a color as color=(some_color, some_alpha)
* :ghpull:`25475`: Stop building 32-bit Linux wheels
* :ghpull:`25484`: Deprecate tostring_rgb.
* :ghpull:`25395`: DOC: user/explain reorg (and moving a lot of tutorials).
* :ghpull:`25425`: Added get_shape as an alias for get_size + tests
* :ghpull:`25281`: Bugfix for loc legend validation
* :ghpull:`25469`: Autoload numpy arrays in get_sample_data.
* :ghpull:`25472`: Use get_sample_data(..., asfileobj=False) less.
* :ghpull:`25444`: Adjust parent axes limits when clearing floating axes.
* :ghpull:`25235`: Update release guide instructions post v3.7.0
* :ghpull:`24531`: Use user-selected format in Tk savefig, rather than inferring it from the filename
* :ghpull:`25467`: DOC: update suptitle example to remove percent_bachelors_degrees csv
* :ghpull:`25454`: Remove unnecessary norm typecheck in tripcolor().
* :ghpull:`25455`: “Inactive” workflow: bump operations to 100
* :ghpull:`25464`: Skip Appveyor for doc only change (second attempt)
* :ghpull:`25430`: Edit error messages for when metadata is passed to ``savefig``
* :ghpull:`23200`: Deprecate empty offsets in get_path_collection_extents
* :ghpull:`25427`: Store FloatingAxes "extremes" info in fewer places.
* :ghpull:`25434`: ci: Install pytz for Pandas nightly wheel
* :ghpull:`25404`: Move _SelectorWidget._props into SpanSelector
* :ghpull:`25421`: wx backend should flush the clipboard before closing it
* :ghpull:`25429`: DOC: remove default logo [ci doc]
* :ghpull:`25423`: DOC/BLD: make logo compatible with pydata-sphinx-theme
* :ghpull:`25424`: “Inactive” workflow: increase operations to 75
* :ghpull:`25138`: Deprecate QuadContourSet.allsegs, .allkinds, .tcolors, .tlinewidths.
* :ghpull:`25415`: Add links for path types and general improvements
* :ghpull:`25420`: Print incorrect tz argument in error message
* :ghpull:`25413`: Make tk backend use native crosshair cursor
* :ghpull:`24984`: Expire deprecations from 3.6
* :ghpull:`25380`: Merge 3.7.1 into main
* :ghpull:`24861`: Documentation fixes
* :ghpull:`24649`: Fix loc legend validation
* :ghpull:`25383`: CI: skip appveyor for doc only change
* :ghpull:`25081`: added a note to avoid f-strings in logging
* :ghpull:`25373`: Expire mpl_toolkits deprecations.
* :ghpull:`25387`: Remove LGTM references and minor doc fixes
* :ghpull:`25382`: Correct patheffects doc
* :ghpull:`25378`: "Inactive" workflow: bump operations-per-run
* :ghpull:`25358`: Remove unused menu field from macos NavigationToolbar2.
* :ghpull:`25352`: MNT: Use WeakKeyDictionary and WeakSet in Grouper
* :ghpull:`20649`: Add colour vision deficiency simulation
* :ghpull:`25287`: Fix unmatched offsetText label color
* :ghpull:`25332`: Support pickling of figures with aligned x/y labels.
* :ghpull:`25334`: Fix for all NANs in contour
* :ghpull:`25335`: "Inactive" workflow: fix typo
* :ghpull:`25163`: GitHub: auto set inactive label
* :ghpull:`22816`: FIX: savefig)...,transparent=True) now makes inset_axes transparent a…
* :ghpull:`25316`: Use setattr_cm more.
* :ghpull:`25258`: Document PowerNorm parameters
* :ghpull:`25209`: MNT: re-organize galleries under one subdir
* :ghpull:`25304`: Add import sorting to ``/plot_types``
* :ghpull:`25296`: Remove straggler 3.7 release notes
* :ghpull:`25147`: Add ruff config to pyproject.toml for devs who are interested
* :ghpull:`25282`: Simplify transforms invalidation system.
* :ghpull:`25270`: merge up 3.7.0
* :ghpull:`25255`: Make default facecolor for subfigures be transparent ("none"). Fix for issue #24910
* :ghpull:`25252`: Support make_compound_path concatenating only empty paths.
* :ghpull:`25211`: Em dashes instead of consecutive hyphens.
* :ghpull:`25243`: Cleanup wx docstrings.
* :ghpull:`25261`: [CI] Skip tests on doc-only changes
* :ghpull:`25192`: Expire wx canvas param deprecation
* :ghpull:`25249`: DOC: remove constrained_layout kwarg from tutorials and user guide
* :ghpull:`25232`: Remove a redundant comma in ``AsinhScale``
* :ghpull:`25195`: DOC: explain how to make a fixed-size axes
* :ghpull:`25207`: Add mpl_round_to_int
* :ghpull:`24983`: Refactor parts of Axis for readability
* :ghpull:`25203`: Replace checking Number with Real
* :ghpull:`25202`: DOC: reorder CI control guidance
* :ghpull:`25200`: Don't handle unknown_symbols in ``\operatorname``.
* :ghpull:`24849`: Stripey ``LineCollection``
* :ghpull:`25177`: Add locator API links to tick-locators example
* :ghpull:`25166`: Clean + comment MaxNLocator
* :ghpull:`25157`: Small tweak in chapter sorting of the example gallery
* :ghpull:`25099`: Add isort (import sorting) to pre-commit hooks
* :ghpull:`25175`: BLD: Unbreak github tests workflow
* :ghpull:`25125`: Use "array" instead of "numpy array" except when emphasis is needed.
* :ghpull:`25144`: FIX: improve CL description and remove constrained_layout text
* :ghpull:`25101`: Deprecate LocationEvent.lastevent.
* :ghpull:`25152`: Group shape/dtype validation logic in image_resample.
* :ghpull:`25145`: BLD: only doc CI build
* :ghpull:`25153`: Delete redundant examples from user gallery that are also present in the annotations tutorial
* :ghpull:`25156`: On macOS, limit symbols exported by extension modules linking FreeType.
* :ghpull:`25150`: DOC: use 'none' in set_layout_engine
* :ghpull:`25131`: FIX: Correctly report command keypress on mac for Tk + Gtk
* :ghpull:`25112`: Connect stream lines if no varying width or color
* :ghpull:`25142`: Minor style tweaks to freetype build.
* :ghpull:`25143`: Don't special-case getSaveFileName in qt_compat anymore.
* :ghpull:`24436`: Make LogLocator only return one tick out of range
* :ghpull:`25135`: Whisker length, more precise description
* :ghpull:`25100`: add section on annotating an artist using axes.annotate
* :ghpull:`24486`: Minor cleanup and add test for offsetbox
* :ghpull:`24964`: Minor cleanup and optimization of Sketch
* :ghpull:`25121`: Inline ContourSet._make_paths.
* :ghpull:`25120`: Consistently document shapes as (M, N), not MxN.
* :ghpull:`24445`: Makefile html-noplot,clean: constrained layout tutorial image handling
* :ghpull:`25115`: Remove tests.py runner from repo root
* :ghpull:`24866`: write addfont example
* :ghpull:`24638`: MNT: Remove auto-flattening of input data to pcolormesh
* :ghpull:`24985`: Deprecate unused/undocumented functions in proj3d
* :ghpull:`25104`: tk blitting to destroyed canvases should be a noop, not a segfault.
* :ghpull:`25108`: Update flake8 per-file ignores
* :ghpull:`25091`: Caching figures generated by plot directive
* :ghpull:`25096`: Remove unused import of re introduced in #23442
* :ghpull:`24749`: Support only positional args in contour. Error if no positional argument.
* :ghpull:`23442`: Remove need to detect math mode in pgf strings
* :ghpull:`25023`: Update Release guide to current practices
* :ghpull:`24816`: [FIX]: Make inset axes transparent on savefig(..., transparent=True)
* :ghpull:`24967`: Rewrite bullseye example to use bar() instead of pcolormesh().
* :ghpull:`24994`: Use ``_axis_map`` instead of ``getattr`` in ``Axes`` and ``Figure``
* :ghpull:`25087`: feat: add new SI prefixes to ticker
* :ghpull:`25073`: MAINT: don't format logs in log call.
* :ghpull:`25061`: Ensure TwoSlopeNorm always has two slopes
* :ghpull:`25064`: Bump mamba-org/provision-with-micromamba from 14 to 15
* :ghpull:`25046`: ci: Re-add the login shell to nightlies jobs
* :ghpull:`24980`: Python 3.9 upgrade
* :ghpull:`25035`: ci: Only attempt to upload nightlies from successful builds
* :ghpull:`24995`: Improve 3D quiver test
* :ghpull:`24992`: Bump NumPy to 1.21
* :ghpull:`25007`: Minor refactoring of Axes3D
* :ghpull:`25021`: Doc: sg section separator
* :ghpull:`25028`: separate out folders in gallery ordering
* :ghpull:`24981`: ENH: pad_inches='layout' for savefig
* :ghpull:`25022`: DOC: tweak array indexing in constrained layout tutorial
* :ghpull:`24990`: Make arguments other than ``renderer`` keyword-only for ``get_tightbbox``
* :ghpull:`25013`: Clarify/shorten gca management in colorbar().
* :ghpull:`25003`: Bump cygwin/cygwin-install-action from 2 to 3
* :ghpull:`24978`: Simplify handling of out-of-bound values ``Colormap.__call__``.
* :ghpull:`24998`: Unbreak Azure CI
* :ghpull:`24907`: DOC/BUILD add ability for conf to skip whole sections
* :ghpull:`22999`: CI: Add a Cygwin run to GHA CI.
* :ghpull:`24919`: Remove support for python 3.8
* :ghpull:`24942`: Expire module deprecations
* :ghpull:`24943`: Remove special casing for PyPy not required anymore
* :ghpull:`24929`: Small unrelated cleanups/style fixes.
* :ghpull:`24923`: Cleanup cbook deprecations and layout
* :ghpull:`24920`: Add --only-binary to nightly pip install
* :ghpull:`24913`: Deprecate Bbox.anchored() with no container.
* :ghpull:`24905`: Remove some long-obsolete commented code in grid_helper_curvelinear.

Issues (185):

* :ghissue:`26765`: [Bug]: Crash in Windows 10 if polar axis lim is lower than lowest data point.
* :ghissue:`26674`: [Doc]: Line3DCollection segments
* :ghissue:`26531`: [Bug]: ValueError thrown when ``levels`` is set to a lower value than ``vmin`` when using ``contours`` method of Axes
* :ghissue:`26029`: [MNT]: Unify tex2uni
* :ghissue:`26637`: [Doc]: Reduce references to set_tight_layout
* :ghissue:`26639`: [Bug]: Incorrect type annotation for legend handes?
* :ghissue:`26600`: [Doc]: contourf demo use of origin keyword
* :ghissue:`26508`: [Doc]: Pyplot Axes – tuple or list?
* :ghissue:`21524`: [Bug]: Removing an inset_axes that shares an axes does not remove it from the sharing group
* :ghissue:`26604`: [Doc]: Inappropriate example in gallery
* :ghissue:`26379`: [doc]: add 'validate' section to install docs
* :ghissue:`19409`: Boxplot: Median line too long after changing linewidth
* :ghissue:`26510`: [Bug]: mathtext silently ignores content after mismatched opening brace
* :ghissue:`26501`: [Bug]: type-checking errors with mypy + matplotlib 3.8.0rc1
* :ghissue:`16657`: Postscript backend gives wrong page sizes
* :ghissue:`11771`: Change PdfPages to default to keep_empty=False and eventually deprecate keep_empty
* :ghissue:`26438`: [ENH]: ``musllinux`` wheels for Alpine
* :ghissue:`26446`: Disallow ``clip`` when ``vmin`` and ``vmax`` are not set in ``matplotlib.colors.Normalize``
* :ghissue:`10002`: can't stop macosx mainloop
* :ghissue:`7551`: automatic papersize selection by ps backend is almost certainly broken
* :ghissue:`15913`: Switching to inline backend closes GUI windows
* :ghissue:`26460`: [TST] Upcoming dependency test failures
* :ghissue:`17566`: Updating an array passed as the xy parameter to annotate updates the anottation
* :ghissue:`24723`: [Doc]: Delete examples made redundant by annotation tutorial rewrite (annotate_simple01, ...)
* :ghissue:`26398`: [Bug]: fig.subplots_adjust and ax.set_yticklabels together can produce unexpected results
* :ghissue:`10767`: ENH: Possibility to decide tick and label position in mplot3d
* :ghissue:`9158`: Angled text not placed correctly with usetex in EPS
* :ghissue:`26400`: [Doc]: advice to use QuadContourSet.collections
* :ghissue:`26409`: [TST] Upcoming dependency test failures
* :ghissue:`26351`: [Doc]: Bad rendering of the title of the MRI example
* :ghissue:`26156`: [Doc]: navigating to the User Guide
* :ghissue:`15785`: xlim_changed not emitted on shared axis
* :ghissue:`26343`: [Bug]: ContourSet.antialiased attribute not present
* :ghissue:`14247`: latex \substack doesn't work
* :ghissue:`17190`: ipython autocomplete does not work for plt.figure()
* :ghissue:`13164`: Figures in windows not tabs
* :ghissue:`23212`: Support ``\middle``
* :ghissue:`26082`: [MNT]: Make cyclers indexable and rely on indexing them rather than itertools.cycle
* :ghissue:`16938`: keyword share_all in ImageGrid class
* :ghissue:`26340`: [ENH]: ContourSet.set_paths
* :ghissue:`26236`: [Bug]: ax.scatter (projection='3d') - incorrect handling of NaN
* :ghissue:`22714`: [Bug]: parasite_axes does not properly handle units
* :ghissue:`22338`: [Bug]: rcParams['legend.loc'] can't use float-tuple like kwarg legend(loc...)
* :ghissue:`25942`: Make ``TexManager.texcache`` private
* :ghissue:`26289`: [Bug]: mathtext caching issue in multi-threaded environment with tight_layout=True
* :ghissue:`26272`: [Bug]: qt window blank after using save button
* :ghissue:`26308`: [Bug]: labels can't be placed at start of contours
* :ghissue:`2369`: Cleaning up kwargs in ContourSet
* :ghissue:`14118`: imshow() should not modify axes aspect if transform != ax.transData.
* :ghissue:`26081`: [ENH]: Add setters for _AxLine._xy1, ._xy2, ._slope
* :ghissue:`25643`: [ENH]: Support for ``\boldsymbol``
* :ghissue:`1366`: Support \boldsymbol. (Feature request.)
* :ghissue:`26283`: [Bug]: set_ticks provides mysterious error message
* :ghissue:`25162`: [Bug]: pcolormesh properties and getter shapes changed w/o notice
* :ghissue:`26261`: [Doc]: Double entries in navigation menu of Using Matplotlib
* :ghissue:`4334`: Axes3D: factor out 3D coordinate guessing from format_coord()
* :ghissue:`22775`: [Bug]: 3d mouse coords values reported in toolbar are meaningless
* :ghissue:`25770`: [ENH]: support RGB(A) in pcolor
* :ghissue:`26031`: [MNT]: decrease timeout on interactive tests locally
* :ghissue:`26264`: [Doc]: Incorrectly drawn bounding box
* :ghissue:`26206`: [Doc]: follow on to #25247
* :ghissue:`26225`: [Bug]: MultiCursor in inset axes
* :ghissue:`22277`: [Doc]: Exchange step() for stairs() in the Plot types - Basic section
* :ghissue:`25493`: [Doc]: users/explain bare index looks bad
* :ghissue:`25114`: [Bug]: matplotlib.path.Path.to_polygons fails with TriContourSet paths
* :ghissue:`26194`: [Bug]: dataLims get replaced by inf for charts with twinx if ax1 is a stackplot
* :ghissue:`6139`: 'QuadContourSet' object has no attribute 'set_visible' or 'set_animated'
* :ghissue:`25128`: [MNT]: Turn ContourSet into a (nearly) plain Collection
* :ghissue:`26100`: [Bug]: Axis multiplier when using plot_surface appears outside of the figure window
* :ghissue:`15518`: Collections could check x- and y- transforms separately to decide whether to autoscale each direction
* :ghissue:`26182`: [TST] Upcoming dependency test failures
* :ghissue:`25857`: [Doc]: gitwash deleting main branch
* :ghissue:`15054`: Improve tests by removing text or using figure comparisons
* :ghissue:`8794`: animation.save problems with ffmpeg
* :ghissue:`26140`: [Doc]: Sort greek/hebrew letters in math docs alphabetically
* :ghissue:`25042`: [Bug]: ``\geqslant``, ``\leqslant`` and ``\eqslantgtr`` are not spaced like their non-slanted versions
* :ghissue:`25014`: [ENH]: Add public method to update ``Legend`` object's loc property .
* :ghissue:`26124`: [Bug]: NavigationToolbar2 mouse over event causes toolbar height increase and axes reposition
* :ghissue:`24663`: [ENH]: Set color of legend shadow
* :ghissue:`7199`: Old whatsnews should be rendered using classic style
* :ghissue:`12926`: Inconsistent behavior of hexbins mincnt parameter, depending on C parameter
* :ghissue:`25030`: [BUG]: Button widgets don't work in inset axes
* :ghissue:`10009`: document event handling with twined axes
* :ghissue:`25477`: Plot ellipse with arrow showing rotation
* :ghissue:`26083`: [Bug]: Star marker (using mathtext) is not center-aligned
* :ghissue:`26015`: [ENH]: Missing mathematical operations
* :ghissue:`8802`: Masked pcolormesh is not tested correctly
* :ghissue:`25244`: [Bug]: DeprecationWarning for pkg_resources.declare_namespace usage in mpl_toolkit
* :ghissue:`25344`: pydata-sphinx-theme 0.13 causes doc builds to fail
* :ghissue:`25590`: [Doc]: type annotations rendering
* :ghissue:`25941`: [Doc]: Rewrite rainbow_text example to use annotate()
* :ghissue:`25497`: [ENH]: hi-res plot directive...
* :ghissue:`25675`: [ENH]: Add get/set_antialiased to Text objects
* :ghissue:`17069`: Error creating AxisGrid with non-default axis class
* :ghissue:`8965`: Add alias for colormaps for grey vs gray English issues
* :ghissue:`25945`: [Bug]: (edge case) no ticks are drawn in colorbars with SymLogNorm
* :ghissue:`25907`: [ENH]: Add test for annotate(textcoods="offset fontsize")
* :ghissue:`25654`: [Bug]: bar/barh don't trigger datetime units
* :ghissue:`19120`: Raise when both singular and plural scatter attributes are specified
* :ghissue:`14233`: Feature Request: Allow setting default AutoMinorLocator
* :ghissue:`25900`: [Doc]: I think you missed a ``fig`` here.
* :ghissue:`18425`: Add fontfamily/labelfont to tick_params
* :ghissue:`25864`: [MNT]: add tests for nargs_error
* :ghissue:`23595`: [Bug]: ``CbarAxesBase.toggle_label`` doesn't seem to work properly
* :ghissue:`25835`: [MNT]: Do not accept arbitrary positional parameters in Figure.add_axes()
* :ghissue:`25833`: [MNT]: Privatize Tick.set_label1() / Tick.set_label2()
* :ghissue:`11181`: [feature request] multiple 3d plots with tied viewing angles
* :ghissue:`25724`: [MNT]: Switch docs/examples to use Noto Sans CJK instead of WenQuanYi Zen Hei as CJK font
* :ghissue:`24779`: [Doc]: windows install instructions do not work
* :ghissue:`24701`: VS Code: Autocomplete and Syntax Highlighting do not work for matplotlib
* :ghissue:`25682`: [Bug]: fill_between{x} does not respect Axes transform
* :ghissue:`23061`: [Bug]: macosx timers don't fire if plt.show() hasn't been called
* :ghissue:`19769`: Memory leak when plotting multiple figures with the macOS backend
* :ghissue:`24331`: [Doc]: Lazy loading for images
* :ghissue:`24689`: [Bug]: Axes3D.set_frame_on not working as documented
* :ghissue:`5087`: Confusing (broken?) colormap name handling
* :ghissue:`22331`: [Bug]: First and or last minor ticks sometimes not plotted
* :ghissue:`19393`: \bf\it in mathtext
* :ghissue:`23171`: [Bug]: axes vlines() / hlines() incorrectly use data coordinate as min when blended transform is applied
* :ghissue:`5234`: Unicode with usetex=True and pgf backend
* :ghissue:`25677`: [Doc]: Axes.hlines and Axes.vlines (and probably others) can accept a single color as well as a list of colors.
* :ghissue:`25649`: [Doc]: backport strategy: inconsistency in guide
* :ghissue:`25582`: [Doc]: Commented Out Code in Downloadable Examples for Toolkits Tutorials
* :ghissue:`25695`: [Bug]: codecov.yml is invalid
* :ghissue:`23810`: [Bug]: Text objects don't take Mathtext into account while wrapping.
* :ghissue:`7560`: Edge cases in eventplot are likely broken
* :ghissue:`25613`: [Doc]: better document default margins
* :ghissue:`25638`: [MNT]: numdecs parameter in ``LogLocator``
* :ghissue:`11375`: PGF output: Contour labels extend beyond figure boundary
* :ghissue:`25608`: [Bug]: ``bbox_inches="tight"`` does not work for writer.grab_frame()
* :ghissue:`25599`: [MNT]: The new default x and ymargin setting is too wasteful
* :ghissue:`25410`: [Bug]: Small Scatter Plot Marker Size Results in Circles
* :ghissue:`25053`: [Doc]: How to show an ASCII hyphen in math text without using TeX?
* :ghissue:`18520`: Matplotlib cannot parse TeX with \text command
* :ghissue:`25560`: [Bug]: legend for Poly3dCollection fails
* :ghissue:`20504`: Support type checking with mypy
* :ghissue:`7160`: pgf_pdflatex test fails on Windows
* :ghissue:`14527`: Log scale messed up in histograms when sharing axes
* :ghissue:`25521`: [Doc]: ``TABLEAU_COLORS`` ``XKCD_COLORS`` etc undocumented
* :ghissue:`5424`: Update colorbar after changing mappable.norm
* :ghissue:`22211`: [Bug]: scroll_event is broken after motion_notify_event in WXAgg
* :ghissue:`24092`: [Bug]: LogLocator with subs argument fragile.
* :ghissue:`23626`: [Bug]: unintended space between comma and digit when using useMathText = True together with comma as decimal separator
* :ghissue:`23154`: [MNT]: requirements/testing/minver.txt could also test oldest-supported pytest version
* :ghissue:`5675`: plt.pause() with threading is extremely slow for MacOSX backend
* :ghissue:`6630`: handling of zeros in log-scale changes irreversibly after user zoom
* :ghissue:`6324`: artist.contains should check that the event occurred in the same figure
* :ghissue:`16561`: Feature request: proper ECDF
* :ghissue:`25426`: [ENH]: Update grid_helper on FloatingSubplot
* :ghissue:`22663`: [Doc]: Consoldiate scatter symbol examples
* :ghissue:`24681`: [ENH]: set facecolor and edgecolor alpha separately
* :ghissue:`5336`: RendererAgg.tostring_rgb merely truncates alpha
* :ghissue:`22494`: [ENH]: Add ``get_shape`` as alias for ``get_size`` in AxesImage, or make that include depth too
* :ghissue:`5327`: Make ``mpl_toolkits`` a non-namespace package
* :ghissue:`9823`: Missing __init__.py file in mpl_toolkits
* :ghissue:`24605`: [Bug]: Validation not performed for ``loc`` argument to ``legend``
* :ghissue:`25445`: [Doc]: Not possible to see upcoming what's new etc?
* :ghissue:`24450`: [MNT]: Fix or drop support for Tk 8.4
* :ghissue:`25453`: [ENH]: Let norm argument accept string values in tripcolour
* :ghissue:`25401`: [Bug]: savefig + jpg + metadata fails with inscrutable error message
* :ghissue:`1735`: ``_path.get_path_collection_extents`` potentially wrong return value
* :ghissue:`25431`: [TST] Upcoming dependency test failures
* :ghissue:`25199`: [Bug]: AttributeError: 'LassoSelector' object has no attribute '_props'
* :ghissue:`25080`: Add note in contrib guide admonishing against use of f strings in logs
* :ghissue:`25165`: [Bug]: offsetText is colored based on tick.color instead of tick.labelcolor
* :ghissue:`25329`: [Bug]: Unable to pickle figure with aligned labels
* :ghissue:`14124`: plt.contour with all NaNs fails assertion in _contour.cpp
* :ghissue:`22674`: [Bug]: savefig(..., transparent=True) does not make inset_axes transparent
* :ghissue:`25303`: CI: isort should check plot_types?
* :ghissue:`25137`: [Bug]: stop responding in demo program "matplotlib/examples/event_handling/lasso_demo.py"
* :ghissue:`24910`: [Bug]: Suptitle not visible with subfigures
* :ghissue:`25222`: [ENH]: add organizational charts to supported plots
* :ghissue:`24796`: [Bug]: gapcolor not supported for LineCollections
* :ghissue:`25172`: [Doc]: cross link locator example with locator API
* :ghissue:`24419`: [Doc]: add from file to font family example
* :ghissue:`23809`: [Bug]: blitting after closing second tkinter embed causes silent crash
* :ghissue:`16580`: Segmentation fault when blitting onto closed figure (TkAgg)
* :ghissue:`24743`: [Bug]: contour raises IndexError if Z is specified as keyword argument
* :ghissue:`24283`: [Bug]: colorbar interacts poorly with TwoSlopeNorm when one slope is infinite
* :ghissue:`24906`: [DOC/BUILD] add ability to selectively build docs
* :ghissue:`24901`: [TST] Upcoming dependency test failures
* :ghissue:`17991`: type stubs for matplotlib
* :ghissue:`17583`: Linter complains about unexpected data-type, however, docs say this is possible
* :ghissue:`15926`: Support for Python Type Hints (PEP 484)
* :ghissue:`13798`: Add PEP484 type hints to the code (For IDE autocompletion / hints)

